@@ -4,18 +4,18 @@
 using namespace std ;
 using namespace Glib ;
 using namespace Gtk ;
-using namespace gtksourceview ;
+using namespace Gsv;
 
 int
 main (int a_argc, char *a_argv[])
 {
     Gtk::Main main_loop (a_argc, a_argv) ;
-    gtksourceview::init () ;
+    Gsv::init () ;
 
     SourceView source_view ;
     RefPtr<SourceBuffer> buffer = source_view.get_source_buffer () ;
     if (!buffer) {
-        cerr << "gtksourceview::SourceView::get_source_buffer () failed" << std::endl ;
+        cerr << "Gsv::SourceView::get_source_buffer () failed" << std::endl ;
         return -1;
     }
     buffer->set_text ("coin") ;
